#! /usr/bin/python
# -*- coding: iso-8859-1 -*-
#
__author__='atareao'
__date__ ='$07/02/2011'
#
# A library for access to google weather api
#
# Copyright (C) 2011 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

import urllib2
import math
from datetime import datetime
from datetime import timedelta
from lxml import etree
from sun import Sun
from moon import Moon
import locale
import gettext
import commwi
from configurator import GConf

locale.setlocale(locale.LC_ALL, '')
gettext.bindtextdomain(commwi.APP, commwi.LANGDIR)
gettext.textdomain(commwi.APP)
_ = gettext.gettext

'''
ICONS
########################################################################
0	tornado
1	tropical storm
2	hurricane
3	severe thunderstorms
4	thunderstorms
5	mixed rain and snow
6	mixed rain and sleet
7	mixed snow and sleet
8	freezing drizzle
9	drizzle
10	freezing rain
11	showers
12	showers
13	snow flurries
14	light snow showers
15	blowing snow
16	snow
17	hail
18	sleet
19	dust
20	foggy
21	haze
22	smoky
23	blustery
24	windy
25	cold
26	cloudy
27	mostly cloudy (night)
28	mostly cloudy (day)
29	partly cloudy (night)
30	partly cloudy (day)
31	clear (night)
32	sunny
33	fair (night)
34	fair (day)
35	mixed rain and hail
36	hot
37	isolated thunderstorms
38	scattered thunderstorms
39	scattered thunderstorms -> Chance of thunderstorms
40	scattered showers -> Chance of rain
41	heavy snow
42	scattered snow showers
43	heavy snow
44	partly cloudy
45	thundershowers
46	snow showers
47	isolated thundershowers
3200	not available
########################################################################
'''
CONDITIONS = {}
CONDITIONS['chance of rain']={'text':_('Chance of rain'),'image':'mwig-chance-of-rain','image-night':'mwig-chance-of-rain-night','icon-dark':'mwid-chance-of-rain','icon-night-dark':'mwid-chance-of-rain-night','icon-light':'mwil-chance-of-rain','icon-night-light':'mwil-chance-of-rain-night'}
CONDITIONS['chance of showers']={'text':_('Chance of showers'),'image':'mwig-chance-of-rain','image-night':'mwig-chance-of-rain-night','icon-dark':'mwid-chance-of-rain','icon-night-dark':'mwid-chance-of-rain-night','icon-light':'mwil-chance-of-rain','icon-night-light':'mwil-chance-of-rain-night'}
CONDITIONS['chance of snow']={'text':_('Chance of snow'),'image':'mwig-chance-of-snow','image-night':'mwig-chance-of-snow-night','icon-dark':'mwid-chance-of-snow','icon-night-dark':'mwid-chance-of-snow-night','icon-light':'mwil-chance-of-snow','icon-night-light':'mwil-chance-of-snow-night'}
CONDITIONS['chance of storm']={'text':_('Chance of storm'),'image':'mwig-chance-of-thunderstorms','image-night':'mwig-chance-of-thunderstorms-night','icon-dark':'mwid-chance-of-thunderstorms','icon-night-dark':'mwid-chance-of-thunderstorms-night','icon-light':'mwil-chance-of-thunderstorms','icon-night-light':'mwil-chance-of-thunderstorms-night'}
CONDITIONS['chance of thunderstorms']={'text':_('Chance of thunderstorms'),'image':'mwig-chance-of-thunderstorms','image-night':'mwig-chance-of-thunderstorms-night','icon-dark':'mwid-chance-of-thunderstorms','icon-night-dark':'mwid-chance-of-thunderstorms-night','icon-light':'mwil-chance-of-thunderstorms','icon-night-light':'mwil-chance-of-thunderstorms-night'}
CONDITIONS['chance of tstorm']={'text':_('Chance of tstorm'),'image':'mwig-chance-of-thunderstorms','image-night':'mwig-chance-of-thunderstorms-night','icon-dark':'mwid-chance-of-thunderstorms','icon-night-dark':'mwid-chance-of-thunderstorms-night','icon-light':'mwil-chance-of-thunderstorms','icon-night-light':'mwil-chance-of-thunderstorms-night'}
CONDITIONS['clear']={'text':_('Clear'),'image':'mwig-clear','image-night':'mwig-clear-night','icon-dark':'mwid-clear','icon-night-dark':'mwid-clear-night','icon-light':'mwil-clear','icon-night-light':'mwil-clear-night'}
CONDITIONS['cloudy']={'text':_('Cloudy'),'image':'mwig-cloudy','image-night':'mwig-cloudy','icon-dark':'mwid-cloudy','icon-night-dark':'mwid-cloudy','icon-light':'mwil-cloudy','icon-night-light':'mwil-cloudy'}
CONDITIONS['light rain']={'text':_('Drizzle'),'image':'mwig-light-rain','image-night':'mwig-light-rain','icon-dark':'mwid-light-rain','icon-night-dark':'mwid-light-rain','icon-light':'mwil-light-rain','icon-night-light':'mwil-light-rain'}
CONDITIONS['dust']={'text':_('Dust'),'image':'mwig-fog','image-night':'mwig-fog-night','icon-dark':'mwid-fog','icon-night-dark':'mwid-fog-night','icon-light':'mwil-fog','icon-night-light':'mwil-fog-night'}
CONDITIONS['flurries']={'text':_('Flurries'),'image':'mwig-flurries','image-night':'mwig-flurries','icon-dark':'mwid-flurries','icon-night-dark':'mwid-flurries','icon-light':'mwil-flurries','icon-night-light':'mwil-flurries'}
CONDITIONS['fog']={'text':_('Fog'),'image':'mwig-fog','image-night':'mwig-fog-night','icon-dark':'mwid-fog','icon-night-dark':'mwid-fog-night','icon-light':'mwil-fog','icon-night-light':'mwil-fog-night'}
CONDITIONS['freezing drizzle']={'text':_('Freezing drizzle'),'image':'mwig-freezing-drizzle','image-night':'mwig-freezing-drizzle','icon-dark':'mwid-freezing-drizzle','icon-night-dark':'mwid-freezing-drizzle','icon-light':'mwil-freezing-drizzle','icon-night-light':'mwil-freezing-drizzle'}
CONDITIONS['hail']={'text':_('Hail'),'image':'mwig-hail','image-night':'mwig-hail','icon-dark':'mwid-hail','icon-night-dark':'mwid-hail','icon-light':'mwil-hail','icon-night-light':'mwil-hail'}
CONDITIONS['haze']={'text':_('Haze'),'image':'mwig-fog','image-night':'mwig-fog-night','icon-dark':'mwid-fog','icon-night-dark':'mwid-fog-night','icon-light':'mwil-fog','icon-night-light':'mwil-fog-night'}
CONDITIONS['icy']={'text':_('Icy'),'image':'mwig-icy','image-night':'mwig-icy','icon-dark':'mwid-icy','icon-night-dark':'mwid-icy','icon-light':'mwil-icy','icon-night-light':'mwil-icy'}
CONDITIONS['isolated showers']={'text':_('Isolated showers'),'image':'mwig-chance-of-rain','image-night':'mwig-chance-of-rain-night','icon-dark':'mwid-chance-of-rain','icon-night-dark':'mwid-chance-of-rain-night','icon-light':'mwil-chance-of-rain','icon-night-light':'mwil-chance-of-rain-night'}
CONDITIONS['isolated thunderstorms']={'text':_('Isolated thunderstorms'),'image':'mwig-chance-of-thunderstorms','image-night':'mwig-chance-of-thunderstorms-night','icon-dark':'mwid-chance-of-thunderstorms','icon-night-dark':'mwid-chance-of-thunderstorms-night','icon-light':'mwil-chance-of-thunderstorms','icon-night-light':'mwil-chance-of-thunderstorms-night'}
CONDITIONS['light rain']={'text':_('Light rain'),'image':'mwig-light-rain','image-night':'mwig-light-rain','icon-dark':'mwid-light-rain','icon-night-dark':'mwid-light-rain','icon-light':'mwil-light-rain','icon-night-light':'mwil-light-rain'}
CONDITIONS['light snow']={'text':_('Light snow'),'image':'mwig-light-snow','image-night':'mwig-light-snow','icon-dark':'mwid-light-snow','icon-night-dark':'mwid-light-snow','icon-light':'mwil-light-snow','icon-night-light':'mwil-light-snow'}
CONDITIONS['mist']={'text':_('Mist'),'image':'mwig-fog','image-night':'mwig-fog-night','icon-dark':'mwid-fog','icon-night-dark':'mwid-fog-night','icon-light':'mwil-fog','icon-night-light':'mwil-fog-night'}
CONDITIONS['mostly cloudy']={'text':_('Mostly cloudy'),'image':'mwig-mostly-cloudy','image-night':'mwig-mostly-cloudy-night','icon-dark':'mwid-mostly-cloudy','icon-night-dark':'mwid-mostly-cloudy-night','icon-light':'mwil-mostly-cloudy','icon-night-light':'mwil-mostly-cloudy-night'}
CONDITIONS['mostly sunny']={'text':_('Mostly sunny'),'image':'mwig-mostly-sunny','image-night':'mwig-mostly-sunny-night','icon-dark':'mwid-mostly-sunny','icon-night-dark':'mwid-mostly-sunny-night','icon-light':'mwil-mostly-sunny','icon-night-light':'mwil-mostly-sunny-night'}
CONDITIONS['not available']={'text':_('Not available'),'image':'mwig-not-available','image-night':'mwig-not-available-night','icon-dark':'mwid-not-available','icon-night-dark':'mwid-not-available','icon-light':'mwil-not-available','icon-night-light':'mwil-not-available'}
CONDITIONS['overcast']={'text':_('Overcast'),'image':'mwig-cloudy','image-night':'mwig-cloudy','icon-dark':'mwid-cloudy','icon-night-dark':'mwid-cloudy','icon-light':'mwil-cloudy','icon-night-light':'mwil-cloudy'}
CONDITIONS['partly cloudy']={'text':_('Partly cloudy'),'image':'mwig-partly-cloudy','image-night':'mwig-partly-cloudy-night','icon-dark':'mwid-partly-cloudy','icon-night-dark':'mwid-partly-cloudy-night','icon-light':'mwil-partly-cloudy','icon-night-light':'mwil-partly-cloudy-night'}
CONDITIONS['partly sunny']={'text':_('Partly sunny'),'image':'mwig-partly-cloudy','image-night':'mwig-partly-cloudy-night','icon-dark':'mwid-partly-cloudy','icon-night-dark':'mwid-partly-cloudy-night','icon-light':'mwil-partly-cloudy','icon-night-light':'mwil-partly-cloudy-night'}
CONDITIONS['rain']={'text':_('Rain'),'image':'mwig-rain','image-night':'mwig-rain','icon-dark':'mwid-rain','icon-night-dark':'mwid-rain','icon-light':'mwil-rain','icon-night-light':'mwil-rain'}
CONDITIONS['rain showers']={'text':_('Rain showers'),'image':'mwig-rain','image-night':'mwig-rain','icon-dark':'mwid-rain','icon-night-dark':'mwid-rain','icon-light':'mwil-rain','icon-night-light':'mwil-rain'}
CONDITIONS['rain and snow']={'text':_('Rain and snow'),'image':'mwig-rain-and-snow','image-night':'mwig-rain-and-snow','icon-dark':'mwid-rain-and-snow','icon-night-dark':'mwid-rain-and-snow','icon-light':'mwil-rain-and-snow','icon-night-light':'mwil-rain-and-snow'}
CONDITIONS['scattered showers']={'text':_('Scattered showers'),'image':'mwig-chance-of-rain','image-night':'mwig-chance-of-rain-night','icon-dark':'mwid-chance-of-rain','icon-night-dark':'mwid-chance-of-rain-night','icon-light':'mwil-chance-of-rain','icon-night-light':'mwil-chance-of-rain-night'}
CONDITIONS['scattered thunderstorms']={'text':_('Scattered thunderstorms'),'image':'mwig-chance-of-thunderstorms','image-night':'mwig-chance-of-thunderstorms-night','icon-dark':'mwid-chance-of-thunderstorms','icon-night-dark':'mwid-chance-of-thunderstorms-night','icon-light':'mwil-chance-of-thunderstorms','icon-night-light':'mwil-chance-of-thunderstorms-night'}
CONDITIONS['showers']={'text':_('Showers'),'image':'mwig-rain','image-night':'mwig-rain','icon-dark':'mwid-rain','icon-night-dark':'mwid-rain','icon-light':'mwil-rain','icon-night-light':'mwil-rain'}
CONDITIONS['sleet']={'text':_('Sleet'),'image':'mwig-rain-and-snow','image-night':'mwig-rain-and-snow','icon-dark':'mwid-rain-and-snow','icon-night-dark':'mwid-rain-and-snow','icon-light':'mwil-rain-and-snow','icon-night-light':'mwil-rain-and-snow'}
CONDITIONS['smoke']={'text':_('Smoke'),'image':'mwig-fog','image-night':'mwig-fog-night','icon-dark':'mwid-fog','icon-night-dark':'mwid-fog-night','icon-light':'mwil-fog','icon-night-light':'mwil-fog-night'}
CONDITIONS['snow']={'text':_('Snow'),'image':'mwig-snow','image-night':'mwig-snow','icon-dark':'mwid-snow','icon-night-dark':'mwid-snow','icon-light':'mwil-snow','icon-night-light':'mwil-snow'}
CONDITIONS['snow showers']={'text':_('Snow showers'),'image':'mwig-rain-and-snow','image-night':'mwig-rain-and-snow','icon-dark':'mwid-rain-and-snow','icon-night-dark':'mwid-rain-and-snow','icon-light':'mwil-rain-and-snow','icon-night-light':'mwil-rain-and-snow'}
CONDITIONS['storm']={'text':_('Storm'),'image':'mwig-storm','image-night':'mwig-storm','icon-dark':'mwid-storm','icon-night-dark':'mwid-storm','icon-light':'mwil-storm','icon-night-light':'mwil-storm'}
CONDITIONS['sunny']={'text':_('Sunny'),'image':'mwig-clear','image-night':'mwig-clear-night','icon-dark':'mwid-clear','icon-night-dark':'mwid-clear-night','icon-light':'mwil-clear','icon-night-light':'mwil-clear-night'}
CONDITIONS['thunderstorm']={'text':_('Thunderstorm'),'image':'mwig-storm','image-night':'mwig-storm','icon-dark':'mwid-storm','icon-night-dark':'mwid-storm','icon-light':'mwil-storm','icon-night-light':'mwil-storm'}
CONDITIONS['windy']={'text':_('Windy'),'image':'mwig-windy','image-night':'mwig-windy','icon-dark':'mwid-windy','icon-night-dark':'mwid-windy','icon-light':'mwil-windy','icon-night-light':'mwil-windy'}
#
#http://en.wikipedia.org/wiki/Boxing_the_compass
#
WINDS = {'n':_('North'),\
'nbe':_('North by east'),\
'nne':_('North-northeast'),\
'nebn':_('Northeast by north'),\
'ne':_('Northeast'),\
'nebe':_('Northeast by east'),\
'ene':_('East-northeast'),\
'ebn':_('East by north'),\
'e':_('East'),\
'ebs':_('East by south'),\
'ese':_('East-southeast'),\
'sebe':_('Southeast by east'),\
'se':_('Southeast'),\
'sebs':_('Southeast by south'),\
'sse':_('South-southeast'),\
'sbe':_('South by east'),\
's':_('South'),\
'sbw':_('South by west'),\
'ssw':_('South-southwest'),\
'swbs':_('Southwest by south'),\
'sw':_('Southwest'),\
'swbw':_('Southwest by west'),\
'wsw':_('West-southwest'),\
'wbs':_('West by south'),\
'w':_('West'),\
'wbn':_('West by north'),\
'wnw':_('West-northwest'),\
'nwbw':_('Northwest by west'),\
'nw':_('Northwest'),\
'nwbn':_('Northwest by north'),\
'nnw':_('North-northwest'),\
'nbw':_('North by west')}

GOOGLE_WEATHER_URL   = 'http://www.google.com/ig/api?weather=,,,%s,%s&hl=en'

def f2c(temperature):
	return (s2f(temperature)-32.0)*5.0/9.0

def s2f(cadena):
	try:
		value = float(cadena)
	except:
		value = 0.0
	return value
	

	
def time_is_lower(time1,time2):
	hora1,minutos1 = time1.split(':')
	hora2,minutos2 = time2.split(':')
	hora1 = int(hora1)
	hora2 = int(hora2)
	minutos1 = int(minutos1)
	minutos2 = int(minutos2)
	if hora1 < hora2:
		return True
	elif hora1 == hora2:
		if minutos1 < minutos2:
			return True
	return False

def time_is_upper(time1,time2):
	hora1,minutos1 = time1.split(':')
	hora2,minutos2 = time2.split(':')
	hora1 = int(hora1)
	hora2 = int(hora2)
	minutos1 = int(minutos1)
	minutos2 = int(minutos2)
	if hora1 > hora2:
		return True
	elif hora1 == hora2:
		if minutos1 > minutos2:
			return True
	return False

def get_humidity(text):
	if text!=None and len(text)>0:
		return text.split(' ')[1].strip()[:-1]
	return ''

def get_text(root,path):	
	r = root.xpath(path)
	if len(r)>0:
		return r[0].text
	return None

def get_data(root,path):	
	r = root.xpath(path)
	if len(r)>0:
		return r[0].attrib['data']
	return None

def get_moon_icon(day):
	moon = Moon(day)
	return moon.icon()
	
def get_moon_phase(day):
	moon = Moon(day)
	return moon.phase()
	
	
def is_day_now(sunrise,sunset):
	hora = ('%s:%s')%(datetime.time(datetime.now()).hour,datetime.time(datetime.now()).minute)
	if time_is_lower(hora,sunrise) or time_is_upper(hora,sunset):
		return False
	return True
	
def get_sunrise(day,longitude,latitude):
	sun = Sun()
	ss = sun.sunRiseSetLocal(day.year, day.month,day.day, s2f(longitude),s2f(latitude))
	return '%s'%(ss[0])
		
def get_sunset(day,longitude,latitude):
	sun = Sun()
	ss = sun.sunRiseSetLocal(day.year, day.month,day.day, s2f(longitude),s2f(latitude))
	return '%s'%(ss[1])

def download_xml(url):
	'''
	dl = MozillaEmulator()           
	xml_response = dl.download(url)
	'''
	#
	handler = urllib2.urlopen(urllib2.Request(url, headers={'User-Agent' : "Magic Browser"}))
	charset = (handler.info().plist[0].split('=')[1])
	if not charset:
		charset = 'utf-8'
	if charset.lower() != 'utf-8':
		xml_response = handler.read().decode(charset).encode('utf-8')
	else:
		xml_response = handler.read()
	handler.close()
	return xml_response

def get_weather_from_google(latitude = 39.4702393, longitude = -0.3768049,temperature_units = 'C',wind_units = 'knots'):
	try:
		#
		lat = int(latitude * 1000000)
		lon = int(longitude * 1000000)
		xml_response = download_xml(GOOGLE_WEATHER_URL % (lat,lon))
		#
		weather_data = {}
		#
		root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/current_conditions')
		if len(root) == 0:
			raise urllib2.URLError('Root 0')
		current_conditions = {}
		temperature = get_data(root[0],'temp_f')
		velocity = get_data(root[0],'wind_condition')
		if velocity != None and len(velocity)>0:
			velocity = s2f(velocity.split(' ')[3])
		else:
			velocity = 0.0
		humidity = get_humidity(get_data(root[0],'humidity'))
		condition = get_data(root[0],'condition').lower()
		current_conditions['condition'] = condition
		current_conditions['condition_text'] = get_condition(condition,'text')
		sunrise = get_sunrise(datetime.today(),longitude,latitude)
		sunset = get_sunset(datetime.today(),longitude,latitude)
		if is_day_now(sunrise,sunset):
			current_conditions['condition_image'] = get_condition(condition,'image')
			current_conditions['condition_icon_dark'] = get_condition(condition,'icon-dark')
			current_conditions['condition_icon_light'] = get_condition(condition,'icon-light')
		else:
			current_conditions['condition_image'] = get_condition(condition,'image-night')
			current_conditions['condition_icon_dark'] = get_condition(condition,'icon-night-dark')
			current_conditions['condition_icon_light'] = get_condition(condition,'icon-night-light')
		current_conditions['temperature'] = get_temperature(temperature,temperature_units)
		current_conditions['humidity'] = '%s '%(humidity)+'%'
		current_conditions['dew_point'] = get_dew_point(humidity,temperature,temperature_units)
		current_conditions['wind_condition'] = get_wind_condition(get_data(root[0],'wind_condition'),wind_units)
		current_conditions['feels_like'] = get_feels_like(temperature,humidity,velocity,temperature_units)
		current_conditions['sunrise'] = sunrise
		current_conditions['sunset'] = sunset
		current_conditions['moon_icon'] = get_moon_icon(datetime.today())
		current_conditions['moon_phase'] = get_moon_phase(datetime.today())
		#
		root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/forecast_conditions')
		forecast_conditions = []
		dia = datetime.today()
		undia = timedelta(days=1)
		for el in root:
			fc = {}
			fc['day_of_week'] = dia.strftime('%A').capitalize()
			fc['low'] = get_temperature(get_data(el,'low'),temperature_units)
			fc['high'] = get_temperature(get_data(el,'high'),temperature_units)
			condition = get_data(el,'condition').lower()
			fc['condition'] = condition
			fc['condition_text'] = get_condition(condition,'text')
			fc['condition_image'] = get_condition(condition,'image')
			fc['condition_icon'] = get_condition(condition,'icon-light')
			fc['sunrise'] = get_sunrise(dia,longitude,latitude)
			fc['sunset'] = get_sunset(dia,longitude,latitude)	
			fc['moon_icon'] = get_moon_icon(dia)
			fc['moon_phase'] = get_moon_phase(dia)
			forecast_conditions.append(fc)
			dia = dia + undia
		#
		root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/forecast_information')
		forecast_information = {}
		forecast_information['city'] = get_data(root[0],'city')
		forecast_information['postal_code'] = get_data(root[0],'postal_code')
		forecast_information['latitude_e6'] = get_data(root[0],'latitude_e6')
		forecast_information['longitude_e6'] = get_data(root[0],'longitude_e6')
		forecast_information['forecast_date'] = get_data(root[0],'forecast_date')
		forecast_information['current_date_time'] = get_data(root[0],'current_date_time')
		forecast_information['unit_system'] = get_data(root[0],'unit_system')
	except urllib2.URLError as e:
		print e
		weather_data = {}
		#
		current_conditions = {}
		current_conditions['condition'] = _('Not available')
		current_conditions['condition_text'] = _('Not available')
		current_conditions['condition_image'] = 'mwig-not-available'
		current_conditions['condition_icon_dark'] = 'mwid-not-available'
		current_conditions['condition_icon_light'] = 'mwil-not-available'
		current_conditions['temperature'] = _('N/A')
		current_conditions['humidity'] = _('N/A')
		current_conditions['dew_point'] = _('N/A')
		current_conditions['wind_condition'] = _('N/A')
		current_conditions['feels_like'] = _('N/A')
		current_conditions['sunrise'] = get_sunrise(datetime.today(),longitude,latitude)
		current_conditions['sunset'] = get_sunset(datetime.today(),longitude,latitude)
		current_conditions['moon_icon'] = get_moon_icon(datetime.today())
		current_conditions['moon_phase'] = get_moon_phase(datetime.today())
		#
		forecast_conditions = []
		dia = datetime.today()
		undia = timedelta(days=1)
		for i in range(0,4):
			fc = {}
			fc['day_of_week'] = dia.strftime('%A').capitalize()
			fc['low'] = ''
			fc['high'] = ''
			fc['condition'] = ''
			fc['condition_text'] = '' 
			fc['condition_image'] = ''
			fc['condition_icon'] = ''	
			fc['sunrise'] = get_sunrise(dia,longitude,latitude)
			fc['sunset'] = get_sunset(dia,longitude,latitude)	
			fc['moon_icon'] = get_moon_icon(dia)
			fc['moon_phase'] = get_moon_phase(dia)
			forecast_conditions.append(fc)
			dia = dia + undia
		#
		forecast_information = {}
		forecast_information['city'] = '...'
		forecast_information['postal_code'] = ''
		forecast_information['latitude_e6'] = ''
		forecast_information['longitude_e6'] = ''
		forecast_information['forecast_date'] = ''
		forecast_information['current_date_time'] = ''
		forecast_information['unit_system'] = 'SI'
	#
	weather_data['current_conditions'] = current_conditions
	weather_data['forecasts'] = forecast_conditions
	weather_data['forecast_information'] = forecast_information
	#
	return weather_data
def get_wind_chill(temperature,wind_velocity):
	#temperature ºF
	#wind_velocity mph
	if temperature<=50.0 and wind_velocity>=3.0:
		wc = 35.74 + 0.6215*temperature-35.76*math.pow(wind_velocity,0.16)+0.4275*temperature*math.pow(wind_velocity,0.16)
		return wc - temperature
	return 0.0

def get_heat_index(temperature,humidity):
	if humidity>0.0 and temperature>=77.0:
		# temperature ºF
		# humidity over 100
		c1 = -42.379
		c2 = 2.04901523
		c3 = 10.14333127
		c4 = -0.22475541
		c5 = -0.00683783
		c6 = -0.05481717
		c7 = 0.00122874
		c8 = 0.00085282
		c9 = -0.00000199
		hi = c1 + c2*temperature + c3*humidity + c4*temperature*humidity\
		+ c5*math.pow(temperature,2.0) + c6*math.pow(humidity,2.0)\
		+ c7*math.pow(temperature,2.0)*humidity + c8*temperature*math.pow(humidity,2.0)\
		+ c9*math.pow(temperature,2.0)*math.pow(humidity,2.0)
		return hi - temperature
	return 0

def get_feels_like(temperature,humidity,wind_velocity,temperature_units):
	# temperature ºF
	# velocity mph
	temperature = s2f(temperature)
	humidity = s2f(humidity)
	wind_velocity = s2f(wind_velocity)
	hi = get_heat_index(temperature,humidity)
	wc = get_wind_chill(temperature,wind_velocity)
	ta = temperature + hi + wc
	return '%s º%s'%(change_temperature(ta,temperature_units),temperature_units)

def get_dew_point(humidity,temperature,temperature_units):
	# humidity (%)
	# temperature (ºF)
	if humidity != None and len(humidity)>0 and temperature != None and len(temperature)>0:
		h = s2f(humidity)
		t = s2f(temperature)
		t = 5.0/9.0*(t - 32.0)
		dp = math.pow(h/100.0,1.0/8.0)*(110.0+t) - 110.0
		dp = redondea(9.0/5.0 * dp + 32)
		return '%s º%s'%(change_temperature(dp,temperature_units),temperature_units)
	return _('n/a')
	
def get_temperature(text,temperature_units):
	if text != None and len(text)>0:
		return '%s º%s'%(change_temperature(s2f(text),temperature_units),temperature_units)
	return _('n/a')
		
def get_wind_condition(text,wind_units):
	if text != None and len(text)>0:
		wind_direction = text.split(' ')[1]
		wind_direction = wind_direction.lower()
		if wind_direction in WINDS.keys():
			wind_direction = WINDS[wind_direction]
		wind_velocity = change_velocity(s2f(text.split(' ')[3]),wind_units)
		if wind_units == 'Beaufort':
			return wind_velocity + ' ' + _('from')+' '+ wind_direction
		else:
			return wind_direction + ' ' + _('at') + ' ' + wind_velocity
	return _('n/a')

def redondea(valor):
	valor = valor * 10.0
	return int(valor)/10.0

def change_temperature(valor,a):
	# initial a in ºF
	if a=='C':
		valor = 5.0/9.0*(valor - 32.0)
	elif a == 'K':
		valor = 5.0/9.0*(valor - 32.0) + 273.15
	return locale.str(redondea(valor))

def change_velocity(valor,a):
	# initial a in mph
	units_u = {'mph':1,'km/h':1.609344,'m/s':0.44704,'knots':0.868976,'ft/s':1.466667}
	units_m = {'mph':_('mph'),'km/h':_('km/h'),'m/s':_('m/s'),'knots':_('knots'),'ft/s':_('ft/s')}
	if a in units_u.keys():
		return '%s %s'%(locale.str(redondea(valor*units_u[a])),units_m[a])
	if a == 'Beaufort':
		if valor <= 1:
			return _('Calm')
		elif valor <= 3:
			return _('Light air')
		elif valor <= 7:
			return _('Light breeze')
		elif valor <= 12:
			return _('Gentle breeze')
		elif valor <= 17:
			return _('Moderate breeze')
		elif valor <= 24:
			return _('Fresh breeze')
		elif valor <= 30:
			return _('Strong breeze')
		elif valor <= 38:
			return _('High wind')
		elif valor <= 46:
			return _('Gale')
		elif valor <= 54:
			return _('Strong gale')
		elif valor <= 63:
			return _('Storm')
		elif valor <= 72:
			return _('Violent storm')
		elif valor >72 :
			return _('Hurricane')
	return ''

def get_condition(condition,tipo):
	if condition != None and len(condition)>0:
		if condition in CONDITIONS.keys():
			return CONDITIONS[condition][tipo]
		else:
			if tipo == 'text':
				return 'Error: %s'%condition
	return CONDITIONS['not available'][tipo]
	
if __name__ == "__main__":
	lat = 39.4702393
	lon = -0.3768049
	res = get_weather_from_google(latitude = lat, longitude = lon)
	print res
	#res = get_weather_from_google(latitude = lat, longitude = lon, hl = 'en')
	'''
	valores = []
	file = open('conditions.txt', 'w')
	for lon in range(-126,126):
		for lat in range(0,71):
			print ('%s,%s')%(lon,lat)
			res = get_weather_from_google(latitude = lat, longitude = lon, hl = 'en')
			if res['forecasts'][0]['condition_en'] in valores:
				pass
			else:
				valores.append(res['forecasts'][0]['condition_en'])
				file.write(('%s\n')%(res['forecasts'][0]['condition_en']))
			if res['forecasts'][1]['condition_en'] in valores:
				pass
			else:
				valores.append(res['forecasts'][1]['condition_en'])
				file.write(('%s\n')%(res['forecasts'][1]['condition_en']))
			if res['forecasts'][2]['condition_en'] in valores:
				pass
			else:
				valores.append(res['forecasts'][2]['condition_en'])
				file.write(('%s\n')%(res['forecasts'][2]['condition_en']))
			if res['forecasts'][3]['condition_en'] in valores:
				pass
			else:
				valores.append(res['forecasts'][3]['condition_en'])
				file.write(('%s\n')%(res['forecasts'][3]['condition_en']))	
	file = open('conditions.txt', 'w')
	for valor in len(valores):
		file.write(('%s\n')%(valor))

	file.close()
	'''
	exit(0)
